<?php

/**
 * WooCommerce hooks start
 * */
/**
 * Verify on checkout
 * */
add_action('woocommerce_checkout_process', 'fcb_verify', 10);
if (!function_exists('fcb_verify')) {

    function fcb_verify() {

        $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
        $config_wc = !empty(get_option('fcb_options')) ? get_option('fcb_options') : array();
        $config = array_merge($config_wp, $config_wc);
        $user_email = sanitize_email($_POST['billing_email']);
        $is_error = fcb_is_error_in_email($user_email);
        if (in_array('WP', $config['fcbwp-check-enable-for'])) {
            $data_val = (isset($config['globel_email_message']) && $config['globel_email_message'] != '') ? $config['globel_email_message'] : __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN);
        } else {
            $data_val = (isset($config['email_message']) && $config['email_message'] != '') ? $config['email_message'] : __('Please update  your email address to any real email address.', FCB_DOMAIN);
        }

        /**
         * Your function's body above, and if error, call this wc_add_notice
         * */
        if ($is_error == 1) {
            wc_add_notice(esc_html(stripslashes($data_val)) . '<div id="is_email_error"></div>', 'error');
        }
    }
}

/**
 * Filter downloads
 * */
add_filter('woocommerce_before_available_downloads', 'fcb_available_downloads', 10);
if (!function_exists('fcb_available_downloads')) {

    function fcb_available_downloads() {
        global $current_user;
        $config = get_option('fcb_options');
        $user_email = $current_user->user_email;
        $is_error = fcb_is_error_in_email($user_email);
        $data_val = (isset($config['email_downloads']) && $config['email_downloads'] != '') ? $config['email_downloads'] : __('Please update your email address to any real email address.', FCB_DOMAIN);
        if ($is_error == 1) {
            echo '<div class="tw-bs4">
            <div class="alert alert-danger">' . esc_html(stripslashes($data_val)) . '</div>
        </div>';
        }
    }
}

/**
 * Display on my account page if valid email does not exist
 * */
add_filter('woocommerce_before_edit_account_form', 'fcb_account_address_form', 10);
if (!function_exists('fcb_account_address_form')) {

    function fcb_account_address_form() {
        global $current_user;
        $config = get_option('fcb_options');
        $user_email = $current_user->user_email;
        $is_error = fcb_is_error_in_email($user_email);
        $data_val = (isset($config['email_profile']) && $config['email_profile'] != '') ? $config['email_profile'] : __('Please update your email address to any real email address.', FCB_DOMAIN);

        if ($is_error == 1) {
            echo '<div class="tw-bs4">
            <div class="alert alert-danger">' . esc_html(stripslashes($data_val)) . '</div>
        </div>';
        }
    }
}

/**
 * Check on registeration page
 * */
add_filter('woocommerce_registration_errors', 'fcb_validate_custom_field', 10, 1);
if (!function_exists('fcb_validate_custom_field')) {

    function fcb_validate_custom_field($errors) {
        global $woocommerce;
        $user_email = sanitize_email($_POST['email']);
        $config = get_option('fcb_options');
        $is_error = fcb_is_error_in_email($user_email);
        $data_val = (isset($config['email_profile']) && $config['email_profile'] != '') ? $config['email_profile'] : __('Please update your email address to any real email address.', FCB_DOMAIN);
        if ($is_error == 1) {
            $errors->add('error', esc_html(stripslashes($data_val)), '');
        }
        return $errors;
    }
}

/**
 * Check on my account page edit
 * */
add_action('woocommerce_save_account_details_errors', 'fcb_validate_myaccount_edit', 10, 1);
if (!function_exists('fcb_validate_myaccount_edit')) {

    function fcb_validate_myaccount_edit($args) {
        global $woocommerce;
        $config = get_option('fcb_options');
        $user_email = sanitize_email($_POST['account_email']);
        $is_error = fcb_is_error_in_email($user_email);
        $data_val = (isset($config['email_profile']) && $config['email_profile'] != '') ? $config['email_profile'] : __('Please update your email address to any real email address.', FCB_DOMAIN);

        if ($is_error == 1) {
            $args->add('error', esc_html(stripslashes($data_val)), '');
        }
    }
}

/**
 * Check if email is valid or not
 * */
if (!function_exists('fcb_is_error_in_email')) {

    function fcb_is_error_in_email($user_email = '') {

        $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
        $config_wc = (in_array('WC', $config_wp['fcbwp-check-enable-for']) && !empty(get_option('fcb_options')) ) ? get_option('fcb_options') : array();
        $config = array_merge($config_wp, $config_wc);
        $all_domains_wp = (in_array('WP', $config_wp['fcbwp-check-enable-for'])) ? explode("\n", $config['domain_list_for_globel']) : array();
        $domain_list = !empty($config['domain_list']) ? $config['domain_list'] : '';
        $all_domains_wc = explode("\n", $domain_list);
        $all_domains = array_merge($all_domains_wp, $all_domains_wc);
        $all_domains = array_map('trim', $all_domains);
        $is_error = 0;
        if (!empty($user_email)) {
            foreach ($all_domains as $single_domain) {
                if (!empty($single_domain) && substr_count($user_email, $single_domain) > 0) {
                    $is_error = 1;
                }
            }
        }
        return $is_error;
    }
}

/**
 *  Verify on checkout for Country & State & Postcode
 *
 * @version 1.0.3
 * */
add_action('woocommerce_checkout_process', 'fcb_Country_verify', 10);
if (!function_exists('fcb_Country_verify')) {

    function fcb_Country_verify() {
        global $woocommerce;
        $config = get_option('fcb_options');

        //Get user country
        $user_country = $_POST['billing_country'];
        $user_state = $_POST['billing_state'];
        $user_pincode = $_POST['billing_postcode'];

        //Check error
        $is_country_error = fcb_country_error_in_country($user_country);
        $is_state_error = fcb_state_error_in_state($user_state);
        $is_pincode_error = fcb_pincode_error($user_pincode);

        // Show message
        $data_val_for_country = (isset($config['country_message']) && $config['country_message'] != '') ? $config['country_message'] : __('Your Selected Country is banned from this site', FCB_DOMAIN);
        $data_val_for_state = (isset($config['state_message']) && $config['state_message'] != '') ? $config['state_message'] : __('Please update your Country address to any real email address.', FCB_DOMAIN);
        $data_val_for_pincode = (isset($config['pin_code_message']) && $config['pin_code_message'] != '') ? $config['pin_code_message'] : __('Your City pin code is blocked by Admin', FCB_DOMAIN);

        // your function's body above, and if error, call this coutry wc_add_notice
        if ($is_country_error == 1) {
            wc_add_notice(esc_html(stripslashes($data_val_for_country)) . '<div id="is_country_error"></div>', 'error');
        }
        // your function's body above, and if error, call this state wc_add_notice
        if ($is_state_error == 1) {
            wc_add_notice(esc_html(stripslashes($data_val_for_state)) . '<div id="is_state_error"></div>', 'error');
        }
        // your function's body above, and if error, call this state wc_add_notice
        if ($is_pincode_error == 1) {
            wc_add_notice(esc_html(stripslashes($data_val_for_pincode)) . '<div id="is_pincode_error"></div>', 'error');
        }
    }
}

/**
 * Check if Counntry is valid or not
 *
 * @version 1.0.3
 * */
if (!function_exists('fcb_country_error_in_country')) {

    function fcb_country_error_in_country($user_country = '') {
        $config = get_option('fcb_options');
        $bannd_country = !empty($config['fcb_selected_country']) ? $config['fcb_selected_country'] : array();

        $is_country_error = 0;
        if (!empty($user_country)) {
            if (!empty($bannd_country) && in_array($user_country, $bannd_country)) {
                $is_country_error = 1;
            }
        }
        return $is_country_error;
    }
}

/**
 * Check if State is valid or not
 *
 * @version 1.0.3
 * */
if (!function_exists('fcb_state_error_in_state')) {

    function fcb_state_error_in_state($user_state = '') {
        $config = get_option('fcb_options');
        $bannd_state = !empty($config['fcb_selected_state']) ? $config['fcb_selected_state'] : array();

        $is_state_error = 0;
        if (!empty($user_state)) {
            if (!empty($bannd_state) && in_array($user_state, $bannd_state)) {
                $is_state_error = 1;
            }
        }
        return $is_state_error;
    }
}

/**
 * Check if City is valid or not
 *
 * @version 1.0.3
 * */
if (!function_exists('fcb_pincode_error')) {

    function fcb_pincode_error($user_pincode = '') {
        $config = !empty(get_option('fcb_wp_options')) ? get_option('fcb_options') : array();
        $bannd_by_pincode_array = explode("\n", $config['pin_code_list']);
        $bannd_by_pincode_array = array_map('trim', $bannd_by_pincode_array);

        $is_pincode_error = 0;
        if (!empty($user_pincode)) {
            foreach ($bannd_by_pincode_array as $single_pin) {
                if (!empty($single_pin) && substr_count($user_pincode, $single_pin) > 0) {
                    $is_pincode_error = 1;
                }
            }
        }
        return $is_pincode_error;
    }
}
// WooCommerce hooks end

/**
 * EDD hooks start
 * Sets the error if the field is empty
 * Be sure to use the same name for your field in the array
 *
 * @version 1.0.3
 * */
add_action('edd_checkout_error_checks', 'sd_validate_custom_edd_checkout_field', 10, 2);
if (!function_exists('sd_validate_custom_edd_checkout_field')) {

    function sd_validate_custom_edd_checkout_field($valid_data, $data) {

        $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
        $config_edd = !empty(get_option('fcb_edd_options')) ? get_option('fcb_edd_options') : array();
        $config = array_merge($config_wp, $config_edd);
        $user_email = sanitize_email($data['edd_email']);
        $is_error = fcb_edd_is_error_in_email($user_email);

        if (in_array('WP', $config_wp['fcbwp-check-enable-for'])) {
            $data_val = (isset($config['globel_email_message']) && $config['globel_email_message'] != '') ? $config['globel_email_message'] : __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN);
        } else {
            $data_val = (isset($config['email_message_for_edd']) && $config['email_message_for_edd'] != '') ? $config['email_message_for_edd'] : __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN);
        }

        // your function's body above, and if error, call this $data_val
        if ($is_error == 1) {
            edd_set_error('invalid_custom_field', __('<span class="error-for-edd">' . $data_val . '</span>'));
        }
    }
}

/**
 * Check if email is valid or not for edd
 *
 * @version 1.0.3
 * */
if (!function_exists('fcb_edd_is_error_in_email')) {

    function fcb_edd_is_error_in_email($user_email = '') {

        $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
        $config_edd = (in_array('EDD', $config_wp['fcbwp-check-enable-for']) && !empty(get_option('fcb_edd_options')) ) ? get_option('fcb_edd_options') : array();

        $config = array_merge($config_wp, $config_edd);

        $all_domains_wp = (in_array('WP', $config_wp['fcbwp-check-enable-for'])) ? explode("\n", $config['domain_list_for_globel']) : array();
        $all_domains_edd = (!empty($config['domain_list_for_edd']) ) ? explode("\n", $config['domain_list_for_edd']) : array();

        $all_domains = array_merge($all_domains_wp, $all_domains_edd);
        $all_domains = array_map('trim', $all_domains);

        $is_error = 0;
        if (!empty($user_email)) {
            foreach ($all_domains as $single_domain) {
                if (!empty($single_domain) && substr_count($user_email, $single_domain) > 0) {
                    $is_error = 1;
                }
            }
        }
        return $is_error;
    }
}

/**
 * Contact Form 7 hooks start
 * Sets the error if the field is empty
 * Be sure to use the same name for your field in the array
 *
 * */
add_filter( 'wpcf7_validate_email', 'custom_email_confirmation_validation_filter', 20, 2 );
add_filter( 'wpcf7_validate_email*', 'custom_email_confirmation_validation_filter', 20, 2 );
function custom_email_confirmation_validation_filter( $result, $tag ) {
    
    $user_gmail_name = $tag->name ;
    $user_email = isset( $_POST[$user_gmail_name] ) ? trim( $_POST[$user_gmail_name] ) : '';
    $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
    $config_cf7 = !empty(get_option('fcb_wpcf7_options')) ? get_option('fcb_wpcf7_options') : array();
    $config = array_merge($config_wp, $config_cf7);
    
    $is_error_cf7_email = fcb_cf7_is_error_in_email($user_email);

    if (in_array('WP', $config_wp['fcbwp-check-enable-for'])) {
        $data_val = (isset($config['globel_email_message']) && $config['globel_email_message'] != '') ? $config['globel_email_message'] : __('Sorry,you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN);
    } else {
        $data_val = (isset($config['email_message_for_wpcf7']) && $config['email_message_for_wpcf7'] != '') ? $config['email_message_for_wpcf7'] : __('Sorry, you can not use any fake email addresses to make spam orders with the site. Try real email addresses like Gmail, Yahoo, etc.', FCB_DOMAIN);
    }

    if($is_error_cf7_email == 1){ 
        $result->invalidate( $tag, esc_html(stripslashes($data_val)));
    }else if($is_error_cf7_email == 2){
        $error_message = esc_html_e("The field is required.", FCB_DOMAIN);
        $result->invalidate( $tag, $error_message);
    }
    return $result;
}

/**
 * Check if email is valid or not for CF7
 *
 * */
if (!function_exists('fcb_cf7_is_error_in_email')) {

    function fcb_cf7_is_error_in_email($user_email = '') {

        $config_wp = !empty(get_option('fcb_wp_options')) ? get_option('fcb_wp_options') : array();
        $config_cf7 = (in_array('WPCF7', $config_wp['fcbwp-check-enable-for']) && !empty(get_option('fcb_wpcf7_options')) ) ? get_option('fcb_wpcf7_options') : array();
        $config = array_merge($config_wp, $config_cf7);
        $all_domains_wp = (in_array('WP', $config_wp['fcbwp-check-enable-for'])) ? explode("\n", $config['domain_list_for_globel']) : array();
        $all_domains_cf7 = (!empty($config['domain_list_for_wpcf7']) ) ? explode("\n", $config['domain_list_for_wpcf7']) : array();
        $all_domains = array_merge($all_domains_wp, $all_domains_cf7);
        $all_domains = array_map('trim', $all_domains);
        
        $is_error_cf7_email = 0;
        if (!empty($user_email)) {
            foreach ($all_domains as $single_domain) {
                if (!empty($single_domain) && substr_count($user_email, $single_domain) > 0) {
                    $is_error_cf7_email = 1;
                }
            }
        }else if( empty($user_email) ){
            $is_error_cf7_email = 2;
        }
        return $is_error_cf7_email;
    }
}
//CF7 hooks end



